@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 1999-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 1999-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -18,12 +18,13 @@
  * Browser identification is performed by examining the HTTP_USER_AGENT
  * environment variable provided by the web server.
  *
- * @todo     http://ajaxian.com/archives/parse-user-agent
- * @author   Chuck Hagenbuch <chuck@horde.org>
- * @author   Jon Parise <jon@horde.org>
- * @category Horde
- * @license  http://www.horde.org/licenses/lgpl21 LGPL
- * @package  Browser
+ * @author    Chuck Hagenbuch <chuck@horde.org>
+ * @author    Jon Parise <jon@horde.org>
+ * @category  Horde
+ * @copyright 1999-2017 Horde LLC
+ * @license   http://www.horde.org/licenses/lgpl21 LGPL
+ * @package   Browser
+ * @todo      http://ajaxian.com/archives/parse-user-agent
  */
 class Horde_Browser
 {
@@ -1198,12 +1199,16 @@ class Horde_Browser
      * @param boolean $inline   True if inline, false if attachment.
      * @param string $cLength   The content-length of this file.
      */
-    public function downloadHeaders($filename = 'unknown', $cType = null,
-                             $inline = false, $cLength = null)
+    public function downloadHeaders(
+        $filename = 'unknown', $cType = null, $inline = false, $cLength = null
+    )
     {
         /* Remove linebreaks from file names. */
         $filename = str_replace(array("\r\n", "\r", "\n"), ' ', $filename);
 
+        /* Remove control characters from file names. */
+        $filename = preg_replace('/[\x00-\x1f]+/', '', $filename);
+
         /* Some browsers don't like spaces in the filename. */
         if ($this->hasQuirk('no_filename_spaces')) {
             $filename = strtr($filename, ' ', '_');
